@@ -301,13 +301,18 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         String recurrencePosition = String.valueOf(object.getFieldContent(CommonCalendarTasksFieldNames.RECURRENCE_POSITION));
         if (recurrencePosition == null || recurrencePosition.equals("0") || recurrencePosition.equals("null"))
             writeExtendedDeleteDataObject(object, CommonConstants.FOLDER, object.getParentFolderID());
-        else
+        else {
+            if (LOG.isTraceEnabled()) {
+                LOG.trace("write deleted appointment to server: " + object.toString());
+            }
+           
             writeExtendedDeleteDataObject(
                 object,
                 CommonCalendarTasksFieldNames.RECURRENCE_POSITION,
                 recurrencePosition,
                 CommonConstants.FOLDER,
                 object.getParentFolderID());
+        }
     }
 
     private boolean shouldDeclineInsteadOfDelete(DataObject object) {
@@ -564,7 +569,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         if (LOG.isDebugEnabled())
             LOG.debug(object.getSession() + " Updating " + _contentType.getID());
         if (LOG.isTraceEnabled())
-            LOG.trace("Updating data object  " + object.toString());
+            LOG.trace("Updating data object on server: " + object.toString());
         checkTypeToWrite(object, _contentType.getID());
 
         Map<String, String> parameters = new HashMap<String, String>();
