@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -48,27 +48,55 @@
  */
 package com.openexchange.usm.database.ox.update;
 
+import java.sql.Connection;
+import java.sql.DatabaseMetaData;
+import java.sql.PreparedStatement;
+import java.sql.SQLException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
-import com.openexchange.usm.database.ox.USMClearTablesUpdateTask;
+import com.openexchange.groupware.update.Schema;
+import com.openexchange.usm.database.ox.TableDefinition;
+import com.openexchange.usm.database.ox.USMUpdateExceptionCodes;
 import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
+import com.openexchange.usm.util.Toolkit;
 
 public class USMClearTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
-	private final USMClearTablesUpdateTask _executor;
-
 	public USMClearTablesUpdateTaskV2(USMUpdateTaskProvider provider) {
 		super(provider);
-		_executor = new USMClearTablesUpdateTask(provider);
 	}
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-		_executor.doPerform(params);
+	    Schema schema = params.getSchema();
+	    int contextId = params.getContextId();
+        Connection con = null;
+        PreparedStatement stmt = null;
+        try {
+            con = _provider.getDatabaseService().getForUpdateTask(contextId);
+            DatabaseMetaData metaData = con.getMetaData();
+            for (int i = TableDefinition.TABLE_NAMES.length - 1; i >= 0; i--) {
+                String tableName = TableDefinition.TABLE_NAMES[i];
+                if (tableExists(tableName, metaData)) {
+                    stmt = con.prepareStatement("DELETE FROM " + tableName + " WHERE cid = ?");
+                    stmt.setInt(1, contextId);
+                    stmt.executeUpdate();
+                    stmt.close();
+                    stmt = null;
+                }
+            }
+        } catch (SQLException e) {
+            throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
+        } finally {
+            if (con != null) {
+                Toolkit.close(stmt);
+                _provider.getDatabaseService().backWritable(contextId, con);
+            }
+        }
 	}
 
 	@Override
     public String[] getDependencies() {
-		return new String[] { USMClearTablesUpdateTask.class.getName(), USMUUIDTablesUpdateTaskV2.class.getName() };
+		return new String[] { USMUUIDTablesUpdateTaskV2.class.getName() };
 	}
 }
