@@ -52,6 +52,7 @@ package com.openexchange.usm.connector.commands;
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
 import static com.openexchange.usm.json.response.ResponseStatusCode.*;
+import java.util.ArrayList;
 import java.util.BitSet;
 import java.util.Collection;
 import java.util.List;
@@ -110,6 +111,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
     
     protected Folder _defaultConcatcsFolder = null;
 
+    protected Folder[] _nonDefaultConcatcFolders = null;
+
     protected NormalCommandHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
         String sessionID = getStringParameter(SESSIONID);
@@ -277,10 +280,20 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
             String user_id = dMember.getUser_id();
             if (user_id != null) {
                 try {
-                    DataObject cachedListMember = getDefaultContacsFolder() != null ? o.getSession().getCachedFolderElement(getDefaultContacsFolder().getID(), o.getContentType(), user_id) : null;
+                    DataObject cachedListMember = getDefaultContactsFolder() != null ? o.getSession().getCachedFolderElement(getDefaultContactsFolder().getID(), o.getContentType(), user_id) : null;
                     if (cachedListMember == null) cachedListMember = o.getSession().getCachedFolderElement(GLOBAL_ADDRESS_BOOK_ID, o.getContentType(), user_id);
+                    if (cachedListMember == null) {
+                        for (Folder cf: getNonDefaultContactFolders()) {
+                            cachedListMember = o.getSession().getCachedFolderElement(cf.getID(), o.getContentType(), user_id);
+                            if (cachedListMember != null) {
+                                break;
+                            }
+                        }
+                    }
                     UUID uuid = cachedListMember != null ? cachedListMember.getUUID() : null;
-                    if (uuid != null) jObj.put(UUID_KEY, uuid.toString());
+                    if (uuid != null) {
+                        jObj.put(UUID_KEY, uuid.toString());
+                    }
                 } catch (NumberFormatException ignored) {
                     // do nothing
                 } catch (USMException ignored) {
@@ -300,46 +313,68 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 
     private Folder determineDefaultCalendarFolder() throws StorageAccessException, USMStorageException {
         Folder[] folders = _session.getCachedFolders();
+        Folder calendarFolder = null;
         for (Folder f : folders) {
             if (DefaultContentTypes.CALENDAR_ID.equals(f.getElementsContentTypeID())) {
                 Object v = f.getFieldContent(FolderConstants.STANDARD_FOLDER);
                 if (v instanceof Boolean) {
                     if (((Boolean) v).booleanValue())
-                        return f;
-                } else {
-                    v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
-                    if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CALENDAR_FOLDER)
-                        return f;
+                        calendarFolder = f;
+                }
+                v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+                if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CALENDAR_FOLDER) {
+                    return f;
                 }
             }
         }
-        return null;
+        return calendarFolder;
     }
     
-    protected Folder getDefaultContacsFolder() throws StorageAccessException, USMStorageException {
+    protected Folder getDefaultContactsFolder() throws StorageAccessException, USMStorageException {
         if (_defaultConcatcsFolder == null)
-            _defaultConcatcsFolder = determineDefaultContacsFolder();
+            _defaultConcatcsFolder = determineDefaultContactsFolder();
         return _defaultConcatcsFolder;
     }
 
-    private Folder determineDefaultContacsFolder() throws StorageAccessException, USMStorageException {
+    private Folder determineDefaultContactsFolder() throws StorageAccessException, USMStorageException {
         Folder[] folders = _session.getCachedFolders();
+        Folder contactFolder = null;
         for (Folder f : folders) {
             if (DefaultContentTypes.CONTACTS_ID.equals(f.getElementsContentTypeID())) {
                 Object v = f.getFieldContent(FolderConstants.STANDARD_FOLDER);
                 if (v instanceof Boolean) {
                     if (((Boolean) v).booleanValue())
-                        return f;
-                } else {
-                    v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
-                    if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CONTACTS_FOLDER)
-                        return f;
+                        contactFolder = f;
+                }  
+                v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+                if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CONTACTS_FOLDER) {
+                    return f;
                 }
             }
         }
-        return null;
+        return contactFolder;
     }
-    
+
+    protected Folder[] getNonDefaultContactFolders() throws StorageAccessException, USMStorageException {
+        if (_nonDefaultConcatcFolders == null)
+            _nonDefaultConcatcFolders = determineNonDefaultContactFolders();
+        return _nonDefaultConcatcFolders;
+    }
+
+   protected Folder[] determineNonDefaultContactFolders() throws StorageAccessException, USMStorageException {
+        Folder[] folders = _session.getCachedFolders();
+        List<Folder> nonDefaultFolders = new ArrayList<Folder>();
+        for (Folder f: folders) {
+            if (DefaultContentTypes.CONTACTS_ID.equals(f.getElementsContentTypeID())) {
+                Object v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+                if ((v instanceof Number) && ((Number) v).intValue() != FolderConstants.DEFAULT_CONTACTS_FOLDER) {
+                    nonDefaultFolders.add(f);
+                }
+            }
+        }
+        return nonDefaultFolders.toArray(new Folder[nonDefaultFolders.size()]);
+    }
+
     private boolean isParentFolderShared(DataObject o) throws USMJSONAPIException {
         Folder parentFolder = o.getParentFolder();
         if (parentFolder == null)
@@ -354,8 +389,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
             }
         if (parentFolder == null)
             return false;
-        else
-            return FolderType.SHARED.matches(parentFolder.getFieldContent(FolderConstants.TYPE));
+        
+        return FolderType.SHARED.matches(parentFolder.getFieldContent(FolderConstants.TYPE));
     }
 
     private boolean isCurrentUserParticipantToChangeException(List<DataObject> exceptions, Object e) {
@@ -458,7 +493,7 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 		return (DataType<PIMAttachments>) fieldType;
 	}
 
-	private USMJSONAPIException generateCantDetermineFolderIDException() throws USMJSONAPIException {
+	private USMJSONAPIException generateCantDetermineFolderIDException() {
 		return new USMJSONAPIException(ConnectorBundleErrorCodes.COMMAND_CANNOT_DETERMINE_FOLDER_UUID,
 				ResponseStatusCode.INTERNAL_ERROR, "Can not determine folder_uuid, list of folders not available");
     }
