@@ -590,6 +590,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private static boolean shouldRetryRequest(JSONResult result) {
         if (result.getResultType() != JSONResultType.Error)
             return false;
+        if (OXJSONErrorCode.MSG_0043.equals(OXJSONUtil.getJSONErrorCode(result.getJSONObject()))) {
+            return false;
+        }
         String errorCategory = OXJSONUtil.getJSONErrorCategory(result.getJSONObject());
         return OXJSONUtil.CATEGORY_RESOURCE_TEMPORARY_DOWN.equals(errorCategory)
         // || OXJSONSupport.CATEGORY_RESOURCE_FULL_OR_BUSY.equals(errorCategory)
@@ -973,7 +976,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private static boolean isValidResourceContentType(String contentType) {
-        return (contentType != null) && (APPLICATION_OCTET_STREAM.equals(contentType) || APPLICATION_OCTET_STREAM_UTF_8.equals(contentType) || contentType.startsWith(IMAGE));
+        return (contentType != null) && (APPLICATION_OCTET_STREAM.equals(contentType) || APPLICATION_OCTET_STREAM_UTF_8.equalsIgnoreCase(contentType) || contentType.startsWith(IMAGE));
     }
 
     @Override
